"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, alarm_model_name: str, key_value: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an alarm.

    Args:
        alarm_model_name(str): The name of the alarm model.
        key_value(str, optional): The value of the key used as a filter to select only the alarms associated with the key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent_data.alarm.describe(ctx, alarm_model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent_data.alarm.describe alarm_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents-data",
        operation="describe_alarm",
        op_kwargs={"alarmModelName": alarm_model_name, "keyValue": key_value},
    )


async def list_all(
    hub, ctx, alarm_model_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists one or more alarms. The operation returns only the metadata associated with each alarm.

    Args:
        alarm_model_name(str): The name of the alarm model.
        next_token(str, optional): The token that you can use to return the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotevent_data.alarm.list_all(ctx, alarm_model_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotevent_data.alarm.list_all alarm_model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotevents-data",
        operation="list_alarms",
        op_kwargs={
            "alarmModelName": alarm_model_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "id"


async def get(
    hub, ctx, identity_pool_id: str, account_id: str = None, logins: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Generates (or retrieves) a Cognito ID. Supplying multiple logins will create an implicit linked account. This is a public API. You do not need any credentials to call this API.

    Args:
        account_id(str, optional): A standard AWS account ID (9+ digits). Defaults to None.
        identity_pool_id(str): An identity pool ID in the format REGION:GUID.
        logins(Dict, optional): A set of optional name-value pairs that map provider names to provider tokens. The available provider names for Logins are as follows:   Facebook: graph.facebook.com    Amazon Cognito user pool: cognito-idp.<region>.amazonaws.com/<YOUR_USER_POOL_ID>, for example, cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789.    Google: accounts.google.com    Amazon: www.amazon.com    Twitter: api.twitter.com    Digits: www.digits.com   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_identity.id_.get(ctx, identity_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_identity.id.get identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-identity",
        operation="get_id",
        op_kwargs={
            "AccountId": account_id,
            "IdentityPoolId": identity_pool_id,
            "Logins": logins,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    repository_name: str,
    image_id: Dict,
    registry_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the scan findings for the specified image.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to describe the image scan findings for. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The repository for the image for which to describe the scan findings.
        image_id(Dict): An object with identifying information for an Amazon ECR image.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeImageScanFindings request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. Defaults to None.
        max_results(int, optional): The maximum number of image scan results returned by DescribeImageScanFindings in paginated output. When this parameter is used, DescribeImageScanFindings only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeImageScanFindings request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeImageScanFindings returns up to 100 results and a nextToken value, if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.scan.finding.describe_all(
                ctx, repository_name=value, image_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.scan.finding.describe_all repository_name=value, image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="describe_image_scan_findings",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageId": image_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, scope: str, web_acl_name: str, web_acl_id: str, rule_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the keys that are currently blocked by a rate-based rule. The maximum number of managed keys that can be blocked for a single rate-based rule is 10,000. If more than 10,000 addresses exceed the rate limit, those with the highest rates are blocked.

    Args:
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        web_acl_name(str): The name of the web ACL. You cannot change the name of a web ACL after you create it.
        web_acl_id(str): The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
        rule_name(str): The name of the rate-based rule to get the keys for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.rate_based_statement_managed_key.get_all(
                ctx, scope=value, web_acl_name=value, web_acl_id=value, rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.rate_based_statement_managed_key.get_all scope=value, web_acl_name=value, web_acl_id=value, rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_rate_based_statement_managed_keys",
        op_kwargs={
            "Scope": scope,
            "WebACLName": web_acl_name,
            "WebACLId": web_acl_id,
            "RuleName": rule_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    ec2_subnet_ids: List,
    launch_profile_protocol_versions: List,
    name: str,
    stream_configuration: Dict,
    studio_component_ids: List,
    studio_id: str,
    client_token: str = None,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a launch profile.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        description(str, optional): The description. Defaults to None.
        ec2_subnet_ids(List): .
        launch_profile_protocol_versions(List): The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
        name(str): The name for the launch profile.
        stream_configuration(Dict): A configuration for a streaming session.
        studio_component_ids(List): Unique identifiers for a collection of studio components that can be used with this launch profile.
        studio_id(str): The studio ID.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.init.create(
                ctx,
                ec2_subnet_ids=value,
                launch_profile_protocol_versions=value,
                name=value,
                stream_configuration=value,
                studio_component_ids=value,
                studio_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.init.create ec2_subnet_ids=value, launch_profile_protocol_versions=value, name=value, stream_configuration=value, studio_component_ids=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_launch_profile",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "ec2SubnetIds": ec2_subnet_ids,
            "launchProfileProtocolVersions": launch_profile_protocol_versions,
            "name": name,
            "streamConfiguration": stream_configuration,
            "studioComponentIds": studio_component_ids,
            "studioId": studio_id,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, launch_profile_id: str, studio_id: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Permanently delete a launch profile.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        launch_profile_id(str): The launch profile ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.init.delete(
                ctx, launch_profile_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.init.delete launch_profile_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_launch_profile",
        op_kwargs={
            "clientToken": client_token,
            "launchProfileId": launch_profile_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, launch_profile_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get a launch profile.

    Args:
        launch_profile_id(str): The launch profile ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.init.get(
                ctx, launch_profile_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.init.get launch_profile_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_launch_profile",
        op_kwargs={"launchProfileId": launch_profile_id, "studioId": studio_id},
    )


async def list_all(
    hub,
    ctx,
    studio_id: str,
    max_results: int = None,
    next_token: str = None,
    principal_id: str = None,
    states: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List all the launch profiles a studio.

    Args:
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        principal_id(str, optional): The principal ID. Defaults to None.
        states(List, optional): A list of states. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.init.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.init.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_launch_profiles",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "principalId": principal_id,
            "states": states,
            "studioId": studio_id,
        },
    )


async def update(
    hub,
    ctx,
    launch_profile_id: str,
    studio_id: str,
    client_token: str = None,
    description: str = None,
    launch_profile_protocol_versions: List = None,
    name: str = None,
    stream_configuration: Dict = None,
    studio_component_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a launch profile.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        description(str, optional): The description. Defaults to None.
        launch_profile_id(str): The launch profile ID.
        launch_profile_protocol_versions(List, optional): The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31". Defaults to None.
        name(str, optional): The name for the launch profile. Defaults to None.
        stream_configuration(Dict, optional): A configuration for a streaming session. Defaults to None.
        studio_component_ids(List, optional): Unique identifiers for a collection of studio components that can be used with this launch profile. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.init.update(
                ctx, launch_profile_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.init.update launch_profile_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="update_launch_profile",
        op_kwargs={
            "clientToken": client_token,
            "description": description,
            "launchProfileId": launch_profile_id,
            "launchProfileProtocolVersions": launch_profile_protocol_versions,
            "name": name,
            "streamConfiguration": stream_configuration,
            "studioComponentIds": studio_component_ids,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    settings: Dict,
    category: str = None,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new preset. For information about job templates see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

    Args:
        category(str, optional): Optional. A category for the preset you are creating. Defaults to None.
        description(str, optional): Optional. A description of the preset you are creating. Defaults to None.
        name(str): The name of the preset you are creating.
        settings(Dict): Settings for preset.
        tags(Dict, optional): The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.preset.create(ctx, name=value, settings=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.preset.create name=value, settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="create_preset",
        op_kwargs={
            "Category": category,
            "Description": description,
            "Name": name,
            "Settings": settings,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently delete a preset you have created.

    Args:
        name(str): The name of the preset to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.preset.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.preset.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="delete_preset",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the JSON for a specific preset.

    Args:
        name(str): The name of the preset.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.preset.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.preset.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="get_preset",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub,
    ctx,
    category: str = None,
    list_by: str = None,
    max_results: int = None,
    next_token: str = None,
    order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a JSON array of up to twenty of your presets. This will return the presets themselves, not just a list of them. To retrieve the next twenty presets, use the nextToken string returned with the array.

    Args:
        category(str, optional): Optionally, specify a preset category to limit responses to only presets from that category. Defaults to None.
        list_by(str, optional): Optional. When you request a list of presets, you can choose to list them alphabetically by NAME or chronologically by CREATION_DATE. If you don't specify, the service will list them by name. Defaults to None.
        max_results(int, optional): Optional. Number of presets, up to twenty, that will be returned at one time. Defaults to None.
        next_token(str, optional): Use this string, provided with the response to a previous request, to request the next batch of presets. Defaults to None.
        order(str, optional): Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.preset.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.preset.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="list_presets",
        op_kwargs={
            "Category": category,
            "ListBy": list_by,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Order": order,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    category: str = None,
    description: str = None,
    settings: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify one of your existing presets.

    Args:
        category(str, optional): The new category for the preset, if you are changing it. Defaults to None.
        description(str, optional): The new description for the preset, if you are changing it. Defaults to None.
        name(str): The name of the preset you are modifying.
        settings(Dict, optional): Settings for preset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.preset.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.preset.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="update_preset",
        op_kwargs={
            "Category": category,
            "Description": description,
            "Name": name,
            "Settings": settings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def request(hub, ctx, build_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a fresh set of credentials for use when uploading a new set of game build files to Amazon GameLift's Amazon S3. This is done as part of the build creation process; see CreateBuild. To request new credentials, specify the build ID as returned with an initial CreateBuild request. If successful, a new set of credentials are returned, along with the S3 storage location associated with the build ID.  Learn more    Create a Build with Files in S3   Related actions   CreateBuild | ListBuilds | DescribeBuild | UpdateBuild | DeleteBuild | All APIs by task

    Args:
        build_id(str): A unique identifier for the build to get credentials for. You can use either the build ID or ARN value. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.upload_credential.request(ctx, build_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.upload_credential.request build_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="request_upload_credentials",
        op_kwargs={"BuildId": build_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, domain_name: str, suggestion_count: int, only_available: bool
) -> Dict:
    r"""
    **Autogenerated function**

    The GetDomainSuggestions operation returns a list of suggested domain names.

    Args:
        domain_name(str): A domain name that you want to use as the basis for a list of possible domain names. The top-level domain (TLD), such as .com, must be a TLD that Route 53 supports. For a list of supported TLDs, see Domains that You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. The domain name can contain only the following characters:   Letters a through z. Domain names are not case sensitive.   Numbers 0 through 9.   Hyphen (-). You can't specify a hyphen at the beginning or end of a label.    Period (.) to separate the labels in the name, such as the . in example.com.   Internationalized domain names are not supported for some top-level domains. To determine whether the TLD that you want to use supports internationalized domain names, see Domains that You Can Register with Amazon Route 53. .
        suggestion_count(int): The number of suggested domain names that you want Route 53 to return. Specify a value between 1 and 50.
        only_available(bool): If OnlyAvailable is true, Route 53 returns only domain names that are available. If OnlyAvailable is false, Route 53 returns domain names without checking whether they're available to be registered. To determine whether the domain is available, you can call checkDomainAvailability for each suggestion.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.suggestion.get_all(
                ctx, domain_name=value, suggestion_count=value, only_available=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.suggestion.get_all domain_name=value, suggestion_count=value, only_available=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="get_domain_suggestions",
        op_kwargs={
            "DomainName": domain_name,
            "SuggestionCount": suggestion_count,
            "OnlyAvailable": only_available,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    subnet_ids: List,
    security_group_ids: List = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPC link.

    Args:
        name(str): The name of the VPC link.
        security_group_ids(List, optional): A list of security group IDs for the VPC link. Defaults to None.
        subnet_ids(List): A list of subnet IDs to include in the VPC link.
        tags(Dict, optional): A list of tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.vpc_link.create(ctx, name=value, subnet_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.vpc_link.create name=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_vpc_link",
        op_kwargs={
            "Name": name,
            "SecurityGroupIds": security_group_ids,
            "SubnetIds": subnet_ids,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, vpc_link_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a VPC link.

    Args:
        vpc_link_id(str): The ID of the VPC link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.vpc_link.delete(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.vpc_link.delete vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_vpc_link",
        op_kwargs={"VpcLinkId": vpc_link_id},
    )


async def get(hub, ctx, vpc_link_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a VPC link.

    Args:
        vpc_link_id(str): The ID of the VPC link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.vpc_link.get(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.vpc_link.get vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_vpc_link",
        op_kwargs={"VpcLinkId": vpc_link_id},
    )


async def get_all(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a collection of VPC links.

    Args:
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.vpc_link.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.vpc_link.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_vpc_links",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, vpc_link_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a VPC link.

    Args:
        name(str, optional): The name of the VPC link. Defaults to None.
        vpc_link_id(str): The ID of the VPC link.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.vpc_link.update(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.vpc_link.update vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_vpc_link",
        op_kwargs={"Name": name, "VpcLinkId": vpc_link_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, source_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays a list of event categories for all event source types, or for a specified source type. For a list of the event categories and source types, go to Amazon Redshift Event Notifications.

    Args:
        source_type(str, optional): The source type, such as cluster or parameter group, to which the described event categories apply. Valid values: cluster, cluster-snapshot, cluster-parameter-group, cluster-security-group, and scheduled-action. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.event.category.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.event.category.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_event_categories",
        op_kwargs={"SourceType": source_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def sign(hub, ctx, fleet_arn: str, username: str) -> Dict:
    r"""
    **Autogenerated function**

    Signs the user out from all of their devices. The user can sign in again if they have valid credentials.

    Args:
        fleet_arn(str): The ARN of the fleet.
        username(str): The name of the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.out_user.sign(ctx, fleet_arn=value, username=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.out_user.sign fleet_arn=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="sign_out_user",
        op_kwargs={"FleetArn": fleet_arn, "Username": username},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "group_older_than_ordering_id"


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    index_id: str,
    ordering_id: int,
    data_source_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of groups that are mapped to users before a given ordering or timestamp identifier.

    Args:
        index_id(str): The identifier of the index for getting a list of groups mapped to users before a given ordering or timestamp identifier.
        data_source_id(str, optional): The identifier of the data source for getting a list of groups mapped to users before a given ordering timestamp identifier. Defaults to None.
        ordering_id(int): The timestamp identifier used for the latest PUT or DELETE action for mapping users to their groups.
        next_token(str, optional):  The next items in the list of groups that go beyond the maximum. . Defaults to None.
        max_results(int, optional):  The maximum results shown for a list of groups that are mapped to users before a given ordering or timestamp identifier. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.group_older_than_ordering_id_.list(
                ctx, index_id=value, ordering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.group_older_than_ordering_id.list index_id=value, ordering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="list_groups_older_than_ordering_id",
        op_kwargs={
            "IndexId": index_id,
            "DataSourceId": data_source_id,
            "OrderingId": ordering_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def enable(hub, ctx, volume_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Enables I/O operations for a volume that had I/O operations disabled because the data on the volume was potentially inconsistent.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        volume_id(str): The ID of the volume.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.volume.io.enable(ctx, volume_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.volume.io.enable volume_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_volume_io",
        op_kwargs={"DryRun": dry_run, "VolumeId": volume_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    directory_arn: str,
    object_reference: Dict,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all available parent paths for any object type such as node, leaf node, policy node, and index node objects. For more information about objects, see Directory Structure. Use this API to evaluate all parents for an object. The call returns all objects from the root of the directory up to the requested object. The API returns the number of paths based on user-defined MaxResults, in case there are multiple paths to the parent. The order of the paths and nodes returned is consistent among multiple API calls unless the objects are deleted or moved. Paths not leading to the directory root are ignored from the target object.

    Args:
        directory_arn(str): The ARN of the directory to which the parent path applies.
        object_reference(Dict): The reference that identifies the object whose parent paths are listed.
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum number of items to be retrieved in a single call. This is an approximate number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.parent.path.list_all(
                ctx, directory_arn=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.parent.path.list_all directory_arn=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_object_parent_paths",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    from_email_address: str,
    content: Dict,
    report_name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new predictive inbox placement test. Predictive inbox placement tests can help you predict how your messages will be handled by various email providers around the world. When you perform a predictive inbox placement test, you provide a sample message that contains the content that you plan to send to your customers. Amazon Pinpoint then sends that message to special email addresses spread across several major email providers. After about 24 hours, the test is complete, and you can use the GetDeliverabilityTestReport operation to view the results of the test.

    Args:
        report_name(str, optional): A unique name that helps you to identify the predictive inbox placement test when you retrieve the results. Defaults to None.
        from_email_address(str): The email address that the predictive inbox placement test email was sent from.
        content(Dict): The HTML body of the message that you sent when you performed the predictive inbox placement test.
        tags(List, optional): An array of objects that define the tags (keys and values) that you want to associate with the predictive inbox placement test. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.deliverability.test_report.create(
                ctx, from_email_address=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.deliverability.test_report.create from_email_address=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="create_deliverability_test_report",
        op_kwargs={
            "ReportName": report_name,
            "FromEmailAddress": from_email_address,
            "Content": content,
            "Tags": tags,
        },
    )


async def get(hub, ctx, report_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the results of a predictive inbox placement test.

    Args:
        report_id(str): A unique string that identifies the predictive inbox placement test.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.deliverability.test_report.get(
                ctx, report_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.deliverability.test_report.get report_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="get_deliverability_test_report",
        op_kwargs={"ReportId": report_id},
    )


async def list_all(hub, ctx, next_token: str = None, page_size: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses. For predictive inbox placement tests that are complete, you can use the GetDeliverabilityTestReport operation to view the results.

    Args:
        next_token(str, optional): A token returned from a previous call to ListDeliverabilityTestReports to indicate the position in the list of predictive inbox placement tests. Defaults to None.
        page_size(int, optional): The number of results to show in a single call to ListDeliverabilityTestReports. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results. The value you specify has to be at least 0, and can be no more than 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.deliverability.test_report.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.deliverability.test_report.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="list_deliverability_test_reports",
        op_kwargs={"NextToken": next_token, "PageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "set"


async def clone(hub, ctx, rule_set_name: str, original_rule_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a receipt rule set by cloning an existing one. All receipt rules and configurations are copied to the new receipt rule set and are completely independent of the source rule set. For information about setting up rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the rule set to create. The name must:   This value can only contain ASCII letters (a-z, A-Z), numbers (0-9), underscores (_), or dashes (-).   Start and end with a letter or number.   Contain less than 64 characters.  .
        original_rule_set_name(str): The name of the rule set to clone.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.clone(
                ctx, rule_set_name=value, original_rule_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.clone rule_set_name=value, original_rule_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="clone_receipt_rule_set",
        op_kwargs={
            "RuleSetName": rule_set_name,
            "OriginalRuleSetName": original_rule_set_name,
        },
    )


async def create(hub, ctx, rule_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty receipt rule set. For information about setting up receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the rule set to create. The name must:   This value can only contain ASCII letters (a-z, A-Z), numbers (0-9), underscores (_), or dashes (-).   Start and end with a letter or number.   Contain less than 64 characters.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.create(ctx, rule_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.create rule_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="create_receipt_rule_set",
        op_kwargs={"RuleSetName": rule_set_name},
    )


async def delete(hub, ctx, rule_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified receipt rule set and all of the receipt rules it contains.  The currently active rule set cannot be deleted.  For information about managing receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the receipt rule set to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.delete(ctx, rule_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.delete rule_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_receipt_rule_set",
        op_kwargs={"RuleSetName": rule_set_name},
    )


async def describe(hub, ctx, rule_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of the specified receipt rule set. For information about managing receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the receipt rule set to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.describe(ctx, rule_set_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.describe rule_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="describe_receipt_rule_set",
        op_kwargs={"RuleSetName": rule_set_name},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the receipt rule sets that exist under your AWS account in the current AWS Region. If there are additional receipt rule sets to be retrieved, you will receive a NextToken that you can provide to the next call to ListReceiptRuleSets to retrieve the additional entries. For information about managing receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        next_token(str, optional): A token returned from a previous call to ListReceiptRuleSets to indicate the position in the receipt rule set list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="list_receipt_rule_sets",
        op_kwargs={"NextToken": next_token},
    )


async def reorder(hub, ctx, rule_set_name: str, rule_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Reorders the receipt rules within a receipt rule set.  All of the rules in the rule set must be represented in this request. That is, this API will return an error if the reorder request doesn't explicitly position all of the rules.  For information about managing receipt rule sets, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        rule_set_name(str): The name of the receipt rule set to reorder.
        rule_names(List): A list of the specified receipt rule set's receipt rules in the order that you want to put them.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.receipt.rule.set_.reorder(
                ctx, rule_set_name=value, rule_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.receipt.rule.set.reorder rule_set_name=value, rule_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="reorder_receipt_rule_set",
        op_kwargs={"RuleSetName": rule_set_name, "RuleNames": rule_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    instance_id: str,
    name: str,
    description: str,
    default_outbound_queue_id: str,
    media_concurrencies: List,
    queue_configs: List = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        name(str): The name of the routing profile. Must not be more than 127 characters.
        description(str): Description of the routing profile. Must not be more than 250 characters.
        default_outbound_queue_id(str): The default outbound queue for the routing profile.
        queue_configs(List, optional): The inbound queues associated with the routing profile. If no queue is added, the agent can make only outbound calls. Defaults to None.
        media_concurrencies(List): The channels that agents can handle in the Contact Control Panel (CCP) for this routing profile.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.init.create(
                ctx,
                instance_id=value,
                name=value,
                description=value,
                default_outbound_queue_id=value,
                media_concurrencies=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.init.create instance_id=value, name=value, description=value, default_outbound_queue_id=value, media_concurrencies=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_routing_profile",
        op_kwargs={
            "InstanceId": instance_id,
            "Name": name,
            "Description": description,
            "DefaultOutboundQueueId": default_outbound_queue_id,
            "QueueConfigs": queue_configs,
            "MediaConcurrencies": media_concurrencies,
            "Tags": tags,
        },
    )


async def describe(hub, ctx, instance_id: str, routing_profile_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified routing profile.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        routing_profile_id(str): The identifier of the routing profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.init.describe(
                ctx, instance_id=value, routing_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.init.describe instance_id=value, routing_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_routing_profile",
        op_kwargs={"InstanceId": instance_id, "RoutingProfileId": routing_profile_id},
    )


async def list_all(
    hub, ctx, instance_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summary information about the routing profiles for the specified Amazon Connect instance. For more information about routing profiles, see Routing Profiles and Create a Routing Profile in the Amazon Connect Administrator Guide.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.routing_profile.init.list_all(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.routing_profile.init.list_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_routing_profiles",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    studio_id: str,
    identity_type: str,
    session_policy_arn: str,
    identity_id: str = None,
    identity_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Maps a user or group to the Amazon EMR Studio specified by StudioId, and applies a session policy to refine Studio permissions for that user or group.

    Args:
        studio_id(str): The ID of the Amazon EMR Studio to which the user or group will be mapped.
        identity_id(str, optional): The globally unique identifier (GUID) of the user or group from the Amazon Web Services SSO Identity Store. For more information, see UserId and GroupId in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_name(str, optional): The name of the user or group. For more information, see UserName and DisplayName in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_type(str): Specifies whether the identity to map to the Amazon EMR Studio is a user or a group.
        session_policy_arn(str): The Amazon Resource Name (ARN) for the session policy that will be applied to the user or group. You should specify the ARN for the session policy that you want to apply, not the ARN of your user role. For more information, see Create an EMR Studio User Role with Session Policies.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.studio.session_mapping.create(
                ctx, studio_id=value, identity_type=value, session_policy_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.studio.session_mapping.create studio_id=value, identity_type=value, session_policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="create_studio_session_mapping",
        op_kwargs={
            "StudioId": studio_id,
            "IdentityId": identity_id,
            "IdentityName": identity_name,
            "IdentityType": identity_type,
            "SessionPolicyArn": session_policy_arn,
        },
    )


async def delete(
    hub,
    ctx,
    studio_id: str,
    identity_type: str,
    identity_id: str = None,
    identity_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Removes a user or group from an Amazon EMR Studio.

    Args:
        studio_id(str): The ID of the Amazon EMR Studio.
        identity_id(str, optional): The globally unique identifier (GUID) of the user or group to remove from the Amazon EMR Studio. For more information, see UserId and GroupId in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_name(str, optional): The name of the user name or group to remove from the Amazon EMR Studio. For more information, see UserName and DisplayName in the Amazon Web Services SSO Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_type(str): Specifies whether the identity to delete from the Amazon EMR Studio is a user or a group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.studio.session_mapping.delete(
                ctx, studio_id=value, identity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.studio.session_mapping.delete studio_id=value, identity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="delete_studio_session_mapping",
        op_kwargs={
            "StudioId": studio_id,
            "IdentityId": identity_id,
            "IdentityName": identity_name,
            "IdentityType": identity_type,
        },
    )


async def get(
    hub,
    ctx,
    studio_id: str,
    identity_type: str,
    identity_id: str = None,
    identity_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Fetches mapping details for the specified Amazon EMR Studio and identity (user or group).

    Args:
        studio_id(str): The ID of the Amazon EMR Studio.
        identity_id(str, optional): The globally unique identifier (GUID) of the user or group. For more information, see UserId and GroupId in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_name(str, optional): The name of the user or group to fetch. For more information, see UserName and DisplayName in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_type(str): Specifies whether the identity to fetch is a user or a group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.studio.session_mapping.get(
                ctx, studio_id=value, identity_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.studio.session_mapping.get studio_id=value, identity_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="get_studio_session_mapping",
        op_kwargs={
            "StudioId": studio_id,
            "IdentityId": identity_id,
            "IdentityName": identity_name,
            "IdentityType": identity_type,
        },
    )


async def list_all(
    hub, ctx, studio_id: str = None, identity_type: str = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all user or group session mappings for the Amazon EMR Studio specified by StudioId.

    Args:
        studio_id(str, optional): The ID of the Amazon EMR Studio. Defaults to None.
        identity_type(str, optional): Specifies whether to return session mappings for users or groups. If not specified, the results include session mapping details for both users and groups. Defaults to None.
        marker(str, optional): The pagination token that indicates the set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.studio.session_mapping.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.studio.session_mapping.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_studio_session_mappings",
        op_kwargs={
            "StudioId": studio_id,
            "IdentityType": identity_type,
            "Marker": marker,
        },
    )


async def update(
    hub,
    ctx,
    studio_id: str,
    identity_type: str,
    session_policy_arn: str,
    identity_id: str = None,
    identity_name: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates the session policy attached to the user or group for the specified Amazon EMR Studio.

    Args:
        studio_id(str): The ID of the Amazon EMR Studio.
        identity_id(str, optional): The globally unique identifier (GUID) of the user or group. For more information, see UserId and GroupId in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_name(str, optional): The name of the user or group to update. For more information, see UserName and DisplayName in the Amazon Web Services SSO Identity Store API Reference. Either IdentityName or IdentityId must be specified. Defaults to None.
        identity_type(str): Specifies whether the identity to update is a user or a group.
        session_policy_arn(str): The Amazon Resource Name (ARN) of the session policy to associate with the specified user or group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.studio.session_mapping.update(
                ctx, studio_id=value, identity_type=value, session_policy_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.studio.session_mapping.update studio_id=value, identity_type=value, session_policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="update_studio_session_mapping",
        op_kwargs={
            "StudioId": studio_id,
            "IdentityId": identity_id,
            "IdentityName": identity_name,
            "IdentityType": identity_type,
            "SessionPolicyArn": session_policy_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, asset_id: str = None, property_id: str = None, property_alias: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets an asset property's current value. For more information, see Querying current values in the IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.

    Args:
        asset_id(str, optional): The ID of the asset. Defaults to None.
        property_id(str, optional): The ID of the asset property. Defaults to None.
        property_alias(str, optional): The alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the IoT SiteWise User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.asset.property_.value.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.asset.property_.value.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="get_asset_property_value",
        op_kwargs={
            "assetId": asset_id,
            "propertyId": property_id,
            "propertyAlias": property_alias,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    savings_plan_id: str,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Savings Plans rates.

    Args:
        savings_plan_id(str): The ID of the Savings Plan.
        filters(List, optional): The filters. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve additional results, make another call with the returned token value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.savingsplan.saving_plan.rate.describe_all(
                ctx, savings_plan_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.savingsplan.saving_plan.rate.describe_all savings_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="savingsplans",
        operation="describe_savings_plan_rates",
        op_kwargs={
            "savingsPlanId": savings_plan_id,
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dataflow_edges: List,
    minimum_viable_contact_duration_seconds: int,
    name: str,
    tracking_config_arn: str,
    contact_post_pass_duration_seconds: int = None,
    contact_pre_pass_duration_seconds: int = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a mission profile.  dataflowEdges is a list of lists of strings. Each lower level list of strings has two elements: a from ARN and a to ARN.

    Args:
        contact_post_pass_duration_seconds(int, optional): Amount of time after a contact ends that you’d like to receive a CloudWatch event indicating the pass has finished. Defaults to None.
        contact_pre_pass_duration_seconds(int, optional): Amount of time prior to contact start you’d like to receive a CloudWatch event indicating an upcoming pass. Defaults to None.
        dataflow_edges(List): A list of lists of ARNs. Each list of ARNs is an edge, with a from Config and a to Config.
        minimum_viable_contact_duration_seconds(int): Smallest amount of time in seconds that you’d like to see for an available contact. AWS Ground Station will not present you with contacts shorter than this duration.
        name(str): Name of a mission profile.
        tags(Dict, optional): Tags assigned to a mission profile. Defaults to None.
        tracking_config_arn(str): ARN of a tracking Config.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.mission_profile.create(
                ctx,
                dataflow_edges=value,
                minimum_viable_contact_duration_seconds=value,
                name=value,
                tracking_config_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.mission_profile.create dataflow_edges=value, minimum_viable_contact_duration_seconds=value, name=value, tracking_config_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="create_mission_profile",
        op_kwargs={
            "contactPostPassDurationSeconds": contact_post_pass_duration_seconds,
            "contactPrePassDurationSeconds": contact_pre_pass_duration_seconds,
            "dataflowEdges": dataflow_edges,
            "minimumViableContactDurationSeconds": minimum_viable_contact_duration_seconds,
            "name": name,
            "tags": tags,
            "trackingConfigArn": tracking_config_arn,
        },
    )


async def delete(hub, ctx, mission_profile_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a mission profile.

    Args:
        mission_profile_id(str): UUID of a mission profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.mission_profile.delete(
                ctx, mission_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.mission_profile.delete mission_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="delete_mission_profile",
        op_kwargs={"missionProfileId": mission_profile_id},
    )


async def get(hub, ctx, mission_profile_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a mission profile.

    Args:
        mission_profile_id(str): UUID of a mission profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.mission_profile.get(ctx, mission_profile_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.mission_profile.get mission_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="get_mission_profile",
        op_kwargs={"missionProfileId": mission_profile_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of mission profiles.

    Args:
        max_results(int, optional): Maximum number of mission profiles returned. Defaults to None.
        next_token(str, optional): Next token returned in the request of a previous ListMissionProfiles call. Used to get the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.mission_profile.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.mission_profile.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_mission_profiles",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    mission_profile_id: str,
    contact_post_pass_duration_seconds: int = None,
    contact_pre_pass_duration_seconds: int = None,
    dataflow_edges: List = None,
    minimum_viable_contact_duration_seconds: int = None,
    name: str = None,
    tracking_config_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a mission profile. Updating a mission profile will not update the execution parameters for existing future contacts.

    Args:
        contact_post_pass_duration_seconds(int, optional): Amount of time after a contact ends that you’d like to receive a CloudWatch event indicating the pass has finished. Defaults to None.
        contact_pre_pass_duration_seconds(int, optional): Amount of time after a contact ends that you’d like to receive a CloudWatch event indicating the pass has finished. Defaults to None.
        dataflow_edges(List, optional): A list of lists of ARNs. Each list of ARNs is an edge, with a from Config and a to Config. Defaults to None.
        minimum_viable_contact_duration_seconds(int, optional): Smallest amount of time in seconds that you’d like to see for an available contact. AWS Ground Station will not present you with contacts shorter than this duration. Defaults to None.
        mission_profile_id(str): UUID of a mission profile.
        name(str, optional): Name of a mission profile. Defaults to None.
        tracking_config_arn(str, optional): ARN of a tracking Config. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.mission_profile.update(
                ctx, mission_profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.mission_profile.update mission_profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="update_mission_profile",
        op_kwargs={
            "contactPostPassDurationSeconds": contact_post_pass_duration_seconds,
            "contactPrePassDurationSeconds": contact_pre_pass_duration_seconds,
            "dataflowEdges": dataflow_edges,
            "minimumViableContactDurationSeconds": minimum_viable_contact_duration_seconds,
            "missionProfileId": mission_profile_id,
            "name": name,
            "trackingConfigArn": tracking_config_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, source_server_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists all ReplicationConfigurations, filtered by Source Server ID.

    Args:
        source_server_id(str): Request to get Replication Configuaration by Source Server ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.init.get(
                ctx, source_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.init.get source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="get_replication_configuration",
        op_kwargs={"sourceServerID": source_server_id},
    )


async def update(
    hub,
    ctx,
    source_server_id: str,
    associate_default_security_group: bool = None,
    bandwidth_throttling: int = None,
    create_public_ip: bool = None,
    data_plane_routing: str = None,
    default_large_staging_disk_type: str = None,
    ebs_encryption: str = None,
    ebs_encryption_key_arn: str = None,
    name: str = None,
    replicated_disks: List = None,
    replication_server_instance_type: str = None,
    replication_servers_security_groups_i_ds: List = None,
    staging_area_subnet_id: str = None,
    staging_area_tags: Dict = None,
    use_dedicated_replication_server: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to update multiple ReplicationConfigurations by Source Server ID.

    Args:
        associate_default_security_group(bool, optional): Update replication configuration associate default Application Migration Service Security group request. Defaults to None.
        bandwidth_throttling(int, optional): Update replication configuration bandwidth throttling request. Defaults to None.
        create_public_ip(bool, optional): Update replication configuration create Public IP request. Defaults to None.
        data_plane_routing(str, optional): Update replication configuration data plane routing request. Defaults to None.
        default_large_staging_disk_type(str, optional): Update replication configuration use default large Staging Disk type request. Defaults to None.
        ebs_encryption(str, optional): Update replication configuration EBS encryption request. Defaults to None.
        ebs_encryption_key_arn(str, optional): Update replication configuration EBS encryption key ARN request. Defaults to None.
        name(str, optional): Update replication configuration name request. Defaults to None.
        replicated_disks(List, optional): Update replication configuration replicated disks request. Defaults to None.
        replication_server_instance_type(str, optional): Update replication configuration Replication Server instance type request. Defaults to None.
        replication_servers_security_groups_i_ds(List, optional): Update replication configuration Replication Server Security Groups IDs request. Defaults to None.
        source_server_id(str): Update replication configuration Source Server ID request.
        staging_area_subnet_id(str, optional): Update replication configuration Staging Area subnet request. Defaults to None.
        staging_area_tags(Dict, optional): Update replication configuration Staging Area Tags request. Defaults to None.
        use_dedicated_replication_server(bool, optional): Update replication configuration use dedicated Replication Server request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.replication_configuration.init.update(
                ctx, source_server_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.replication_configuration.init.update source_server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="update_replication_configuration",
        op_kwargs={
            "associateDefaultSecurityGroup": associate_default_security_group,
            "bandwidthThrottling": bandwidth_throttling,
            "createPublicIP": create_public_ip,
            "dataPlaneRouting": data_plane_routing,
            "defaultLargeStagingDiskType": default_large_staging_disk_type,
            "ebsEncryption": ebs_encryption,
            "ebsEncryptionKeyArn": ebs_encryption_key_arn,
            "name": name,
            "replicatedDisks": replicated_disks,
            "replicationServerInstanceType": replication_server_instance_type,
            "replicationServersSecurityGroupsIDs": replication_servers_security_groups_i_ds,
            "sourceServerID": source_server_id,
            "stagingAreaSubnetId": staging_area_subnet_id,
            "stagingAreaTags": staging_area_tags,
            "useDedicatedReplicationServer": use_dedicated_replication_server,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, api_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a CORS configuration.

    Args:
        api_id(str): The API identifier.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.cors_configuration.delete(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.cors_configuration.delete api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_cors_configuration",
        op_kwargs={"ApiId": api_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, device_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a device from its current room. The device continues to be connected to the Wi-Fi network and is still registered to the account. The device settings and skills are removed from the room.

    Args:
        device_arn(str, optional): The ARN of the device to disassociate from a room. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.from_room.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.from_room.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="disassociate_device_from_room",
        op_kwargs={"DeviceArn": device_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, rest_api_id: str, model_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Generates a sample mapping template that can be used to transform a payload into the structure of a model.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        model_name(str): [Required] The name of the model for which to generate a template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.model.template.get(
                ctx, rest_api_id=value, model_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.model.template.get rest_api_id=value, model_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_model_template",
        op_kwargs={"restApiId": rest_api_id, "modelName": model_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    local_gateway_route_table_id: str,
    vpc_id: str,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified VPC with the specified local gateway route table.

    Args:
        local_gateway_route_table_id(str): The ID of the local gateway route table.
        vpc_id(str): The ID of the VPC.
        tag_specifications(List, optional): The tags to assign to the local gateway route table VPC association. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.table.vpc_association.create(
                ctx, local_gateway_route_table_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.table.vpc_association.create local_gateway_route_table_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_local_gateway_route_table_vpc_association",
        op_kwargs={
            "LocalGatewayRouteTableId": local_gateway_route_table_id,
            "VpcId": vpc_id,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub, ctx, local_gateway_route_table_vpc_association_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified association between a VPC and local gateway route table.

    Args:
        local_gateway_route_table_vpc_association_id(str): The ID of the association.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.table.vpc_association.delete(
                ctx, local_gateway_route_table_vpc_association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.table.vpc_association.delete local_gateway_route_table_vpc_association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_local_gateway_route_table_vpc_association",
        op_kwargs={
            "LocalGatewayRouteTableVpcAssociationId": local_gateway_route_table_vpc_association_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    local_gateway_route_table_vpc_association_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified associations between VPCs and local gateway route tables.

    Args:
        local_gateway_route_table_vpc_association_ids(List, optional): The IDs of the associations. Defaults to None.
        filters(List, optional): One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-route-table-id - The ID of the local gateway route table.    local-gateway-route-table-vpc-association-id - The ID of the association.    state - The state of the association.    vpc-id - The ID of the VPC.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.route.table.vpc_association.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.route.table.vpc_association.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_local_gateway_route_table_vpc_associations",
        op_kwargs={
            "LocalGatewayRouteTableVpcAssociationIds": local_gateway_route_table_vpc_association_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    resource_type: str,
    resource_id: str,
    compliance_types: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the evaluation results for the specified AWS resource. The results indicate which AWS Config rules were used to evaluate the resource, when each rule was last used, and whether the resource complies with each rule.

    Args:
        resource_type(str): The type of the AWS resource for which you want compliance information.
        resource_id(str): The ID of the AWS resource for which you want compliance information.
        compliance_types(List, optional): Filters the results by compliance. The allowed values are COMPLIANT, NON_COMPLIANT, and NOT_APPLICABLE. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.compliance.detail_by.resource.get(
                ctx, resource_type=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.compliance.detail_by.resource.get resource_type=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_compliance_details_by_resource",
        op_kwargs={
            "ResourceType": resource_type,
            "ResourceId": resource_id,
            "ComplianceTypes": compliance_types,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    s3_bucket_name: str,
    s3_key_prefix: str = None,
    sns_topic_name: str = None,
    include_global_service_events: bool = None,
    is_multi_region_trail: bool = None,
    enable_log_file_validation: bool = None,
    cloud_watch_logs_log_group_arn: str = None,
    cloud_watch_logs_role_arn: str = None,
    kms_key_id: str = None,
    is_organization_trail: bool = None,
    tags_list: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a trail that specifies the settings for delivery of log data to an Amazon S3 bucket.

    Args:
        name(str): Specifies the name of the trail. The name must meet the following requirements:   Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)   Start with a letter or number, and end with a letter or number   Be between 3 and 128 characters   Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are invalid.   Not be in IP address format (for example, 192.168.5.4)  .
        s3_bucket_name(str): Specifies the name of the Amazon S3 bucket designated for publishing log files. See Amazon S3 Bucket Naming Requirements.
        s3_key_prefix(str, optional): Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files. The maximum length is 200 characters. Defaults to None.
        sns_topic_name(str, optional): Specifies the name of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters. Defaults to None.
        include_global_service_events(bool, optional): Specifies whether the trail is publishing events from global services such as IAM to the log files. Defaults to None.
        is_multi_region_trail(bool, optional): Specifies whether the trail is created in the current region or in all regions. The default is false, which creates a trail only in the region where you are signed in. As a best practice, consider creating trails that log events in all regions. Defaults to None.
        enable_log_file_validation(bool, optional): Specifies whether log file integrity validation is enabled. The default is false.  When you disable log file integrity validation, the chain of digest files is broken after one hour. CloudTrail will not create digest files for log files that were delivered during a period in which log file integrity validation was disabled. For example, if you enable log file integrity validation at noon on January 1, disable it at noon on January 2, and re-enable it at noon on January 10, digest files will not be created for the log files delivered from noon on January 2 to noon on January 10. The same applies whenever you stop CloudTrail logging or delete a trail. . Defaults to None.
        cloud_watch_logs_log_group_arn(str, optional): Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered. Not required unless you specify CloudWatchLogsRoleArn. Defaults to None.
        cloud_watch_logs_role_arn(str, optional): Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group. Defaults to None.
        kms_key_id(str, optional): Specifies the KMS key ID to use to encrypt the logs delivered by CloudTrail. The value can be an alias name prefixed by "alias/", a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier. Examples:   alias/MyAliasName   arn:aws:kms:us-east-2:123456789012:alias/MyAliasName   arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012   12345678-1234-1234-1234-123456789012  . Defaults to None.
        is_organization_trail(bool, optional): Specifies whether the trail is created for all accounts in an organization in AWS Organizations, or only for the current AWS account. The default is false, and cannot be true unless the call is made on behalf of an AWS account that is the master account for an organization in AWS Organizations. Defaults to None.
        tags_list(List, optional): A list of tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.create(
                ctx, name=value, s3_bucket_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.create name=value, s3_bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="create_trail",
        op_kwargs={
            "Name": name,
            "S3BucketName": s3_bucket_name,
            "S3KeyPrefix": s3_key_prefix,
            "SnsTopicName": sns_topic_name,
            "IncludeGlobalServiceEvents": include_global_service_events,
            "IsMultiRegionTrail": is_multi_region_trail,
            "EnableLogFileValidation": enable_log_file_validation,
            "CloudWatchLogsLogGroupArn": cloud_watch_logs_log_group_arn,
            "CloudWatchLogsRoleArn": cloud_watch_logs_role_arn,
            "KmsKeyId": kms_key_id,
            "IsOrganizationTrail": is_organization_trail,
            "TagsList": tags_list,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a trail. This operation must be called from the region in which the trail was created. DeleteTrail cannot be called on the shadow trails (replicated trails in other regions) of a trail that is enabled in all regions.

    Args:
        name(str): Specifies the name or the CloudTrail ARN of the trail to be deleted. The format of a trail ARN is: arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="delete_trail",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub, ctx, trail_name_list: List = None, include_shadow_trails: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves settings for one or more trails associated with the current region for your account.

    Args:
        trail_name_list(List, optional): Specifies a list of trail names, trail ARNs, or both, of the trails to describe. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail  If an empty list is specified, information for the trail in the current region is returned.   If an empty list is specified and IncludeShadowTrails is false, then information for all trails in the current region is returned.   If an empty list is specified and IncludeShadowTrails is null or true, then information for all trails in the current region and any associated shadow trails in other regions is returned.    If one or more trail names are specified, information is returned only if the names match the names of trails belonging only to the current region. To return information about a trail in another region, you must specify its trail ARN. . Defaults to None.
        include_shadow_trails(bool, optional): Specifies whether to include shadow trails in the response. A shadow trail is the replication in a region of a trail that was created in a different region, or in the case of an organization trail, the replication of an organization trail in member accounts. If you do not include shadow trails, organization trails in a member account and region replication trails will not be returned. The default is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="describe_trails",
        op_kwargs={
            "trailNameList": trail_name_list,
            "includeShadowTrails": include_shadow_trails,
        },
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns settings information for a specified trail.

    Args:
        name(str): The name or the Amazon Resource Name (ARN) of the trail for which you want to retrieve settings information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="cloudtrail", operation="get_trail", op_kwargs={"Name": name}
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists trails that are in the current account.

    Args:
        next_token(str, optional): The token to use to get the next page of results after a previous API call. This token must be passed in with the same parameters that were specified in the the original call. For example, if the original call specified an AttributeKey of 'Username' with a value of 'root', the call with NextToken should include those same parameters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="list_trails",
        op_kwargs={"NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    s3_bucket_name: str = None,
    s3_key_prefix: str = None,
    sns_topic_name: str = None,
    include_global_service_events: bool = None,
    is_multi_region_trail: bool = None,
    enable_log_file_validation: bool = None,
    cloud_watch_logs_log_group_arn: str = None,
    cloud_watch_logs_role_arn: str = None,
    kms_key_id: str = None,
    is_organization_trail: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the settings that specify delivery of log files. Changes to a trail do not require stopping the CloudTrail service. Use this action to designate an existing bucket for log delivery. If the existing bucket has previously been a target for CloudTrail log files, an IAM policy exists for the bucket. UpdateTrail must be called from the region in which the trail was created; otherwise, an InvalidHomeRegionException is thrown.

    Args:
        name(str): Specifies the name of the trail or trail ARN. If Name is a trail name, the string must meet the following requirements:   Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)   Start with a letter or number, and end with a letter or number   Be between 3 and 128 characters   Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are invalid.   Not be in IP address format (for example, 192.168.5.4)   If Name is a trail ARN, it must be in the format:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .
        s3_bucket_name(str, optional): Specifies the name of the Amazon S3 bucket designated for publishing log files. See Amazon S3 Bucket Naming Requirements. Defaults to None.
        s3_key_prefix(str, optional): Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files. The maximum length is 200 characters. Defaults to None.
        sns_topic_name(str, optional): Specifies the name of the Amazon SNS topic defined for notification of log file delivery. The maximum length is 256 characters. Defaults to None.
        include_global_service_events(bool, optional): Specifies whether the trail is publishing events from global services such as IAM to the log files. Defaults to None.
        is_multi_region_trail(bool, optional): Specifies whether the trail applies only to the current region or to all regions. The default is false. If the trail exists only in the current region and this value is set to true, shadow trails (replications of the trail) will be created in the other regions. If the trail exists in all regions and this value is set to false, the trail will remain in the region where it was created, and its shadow trails in other regions will be deleted. As a best practice, consider using trails that log events in all regions. Defaults to None.
        enable_log_file_validation(bool, optional): Specifies whether log file validation is enabled. The default is false.  When you disable log file integrity validation, the chain of digest files is broken after one hour. CloudTrail will not create digest files for log files that were delivered during a period in which log file integrity validation was disabled. For example, if you enable log file integrity validation at noon on January 1, disable it at noon on January 2, and re-enable it at noon on January 10, digest files will not be created for the log files delivered from noon on January 2 to noon on January 10. The same applies whenever you stop CloudTrail logging or delete a trail. . Defaults to None.
        cloud_watch_logs_log_group_arn(str, optional): Specifies a log group name using an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered. Not required unless you specify CloudWatchLogsRoleArn. Defaults to None.
        cloud_watch_logs_role_arn(str, optional): Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group. Defaults to None.
        kms_key_id(str, optional): Specifies the KMS key ID to use to encrypt the logs delivered by CloudTrail. The value can be an alias name prefixed by "alias/", a fully specified ARN to an alias, a fully specified ARN to a key, or a globally unique identifier. Examples:   alias/MyAliasName   arn:aws:kms:us-east-2:123456789012:alias/MyAliasName   arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012   12345678-1234-1234-1234-123456789012  . Defaults to None.
        is_organization_trail(bool, optional): Specifies whether the trail is applied to all accounts in an organization in AWS Organizations, or only for the current AWS account. The default is false, and cannot be true unless the call is made on behalf of an AWS account that is the master account for an organization in AWS Organizations. If the trail is not an organization trail and this is set to true, the trail will be created in all AWS accounts that belong to the organization. If the trail is an organization trail and this is set to false, the trail will remain in the current AWS account but be deleted from all member accounts in the organization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="update_trail",
        op_kwargs={
            "Name": name,
            "S3BucketName": s3_bucket_name,
            "S3KeyPrefix": s3_key_prefix,
            "SnsTopicName": sns_topic_name,
            "IncludeGlobalServiceEvents": include_global_service_events,
            "IsMultiRegionTrail": is_multi_region_trail,
            "EnableLogFileValidation": enable_log_file_validation,
            "CloudWatchLogsLogGroupArn": cloud_watch_logs_log_group_arn,
            "CloudWatchLogsRoleArn": cloud_watch_logs_role_arn,
            "KmsKeyId": kms_key_id,
            "IsOrganizationTrail": is_organization_trail,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete_multiple(
    hub, ctx, bucket: str, expected_bucket_owner: str = None
) -> None:
    r"""
    **Autogenerated function**

    Removes OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:PutBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy. For information about Amazon S3 Object Ownership, see Using Object Ownership.  The following operations are related to DeleteBucketOwnershipControls:    GetBucketOwnershipControls     PutBucketOwnershipControls

    Args:
        bucket(str): The Amazon S3 bucket whose OwnershipControls you want to delete. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.ownership_control.delete_multiple(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.ownership_control.delete_multiple bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_ownership_controls",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get_all(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:GetBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy.  For information about Amazon S3 Object Ownership, see Using Object Ownership.  The following operations are related to GetBucketOwnershipControls:    PutBucketOwnershipControls     DeleteBucketOwnershipControls

    Args:
        bucket(str): The name of the Amazon S3 bucket whose OwnershipControls you want to retrieve. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.ownership_control.get_all(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.ownership_control.get_all bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_ownership_controls",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put_multiple(
    hub,
    ctx,
    bucket: str,
    ownership_controls: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates or modifies OwnershipControls for an Amazon S3 bucket. To use this operation, you must have the s3:PutBucketOwnershipControls permission. For more information about Amazon S3 permissions, see Specifying Permissions in a Policy.  For information about Amazon S3 Object Ownership, see Using Object Ownership.  The following operations are related to PutBucketOwnershipControls:    GetBucketOwnershipControls     DeleteBucketOwnershipControls

    Args:
        bucket(str): The name of the Amazon S3 bucket whose OwnershipControls you want to set.
        content_md5(str, optional): The MD5 hash of the OwnershipControls request body.  For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
        ownership_controls(Dict): The OwnershipControls (BucketOwnerPreferred or ObjectWriter) that you want to apply to this Amazon S3 bucket.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.ownership_control.put_multiple(
                ctx, bucket=value, ownership_controls=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.ownership_control.put_multiple bucket=value, ownership_controls=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_ownership_controls",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "ExpectedBucketOwner": expected_bucket_owner,
            "OwnershipControls": ownership_controls,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    network_interface_id: str,
    permission: str,
    aws_account_id: str = None,
    aws_service: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Grants an Amazon Web Services-authorized account permission to attach the specified network interface to an instance in their account. You can grant permission to a single Amazon Web Services account only, and only one account at a time.

    Args:
        network_interface_id(str): The ID of the network interface.
        aws_account_id(str, optional): The Amazon Web Services account ID. Defaults to None.
        aws_service(str, optional): The Amazon Web Service. Currently not supported. Defaults to None.
        permission(str): The type of permission to grant.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.permission.create(
                ctx, network_interface_id=value, permission=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.permission.create network_interface_id=value, permission=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_network_interface_permission",
        op_kwargs={
            "NetworkInterfaceId": network_interface_id,
            "AwsAccountId": aws_account_id,
            "AwsService": aws_service,
            "Permission": permission,
            "DryRun": dry_run,
        },
    )


async def delete(
    hub,
    ctx,
    network_interface_permission_id: str,
    force: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a permission for a network interface. By default, you cannot delete the permission if the account for which you're removing the permission has attached the network interface to an instance. However, you can force delete the permission, regardless of any attachment.

    Args:
        network_interface_permission_id(str): The ID of the network interface permission.
        force(bool, optional): Specify true to remove the permission even if the network interface is attached to an instance. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.permission.delete(
                ctx, network_interface_permission_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.permission.delete network_interface_permission_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_interface_permission",
        op_kwargs={
            "NetworkInterfacePermissionId": network_interface_permission_id,
            "Force": force,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    network_interface_permission_ids: List = None,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the permissions for your network interfaces.

    Args:
        network_interface_permission_ids(List, optional): One or more network interface permission IDs. Defaults to None.
        filters(List, optional): One or more filters.    network-interface-permission.network-interface-permission-id - The ID of the permission.    network-interface-permission.network-interface-id - The ID of the network interface.    network-interface-permission.aws-account-id - The Amazon Web Services account ID.    network-interface-permission.aws-service - The Amazon Web Service.    network-interface-permission.permission - The type of permission (INSTANCE-ATTACH | EIP-ASSOCIATE).  . Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. If this parameter is not specified, up to 50 results are returned by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.permission.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.permission.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_network_interface_permissions",
        op_kwargs={
            "NetworkInterfacePermissionIds": network_interface_permission_ids,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def post(hub, ctx, data: bytes, connection_id: str) -> None:
    r"""
    **Autogenerated function**

    Sends the provided data to the specified connection.

    Args:
        data(bytes): The data to be sent to the client specified by its connection id.
        connection_id(str): The identifier of the connection that a specific client is using.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewaymanagementapi.to_connection.post(
                ctx, data=value, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewaymanagementapi.to_connection.post data=value, connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewaymanagementapi",
        operation="post_to_connection",
        op_kwargs={"Data": data, "ConnectionId": connection_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, anomaly_subscription: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds a subscription to a cost anomaly detection monitor. You can use each subscription to define subscribers with email or SNS notifications. Email subscribers can set a dollar threshold and a time frequency for receiving notifications.

    Args:
        anomaly_subscription(Dict):  The cost anomaly subscription object that you want to create. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.subscription.create(ctx, anomaly_subscription=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.subscription.create anomaly_subscription=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="create_anomaly_subscription",
        op_kwargs={"AnomalySubscription": anomaly_subscription},
    )


async def delete(hub, ctx, subscription_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a cost anomaly subscription.

    Args:
        subscription_arn(str):  The unique identifier of the cost anomaly subscription that you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.subscription.delete(ctx, subscription_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.subscription.delete subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="delete_anomaly_subscription",
        op_kwargs={"SubscriptionArn": subscription_arn},
    )


async def get_all(
    hub,
    ctx,
    subscription_arn_list: List = None,
    monitor_arn: str = None,
    next_page_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the cost anomaly subscription objects for your account. You can filter using a list of cost anomaly monitor Amazon Resource Names (ARNs).

    Args:
        subscription_arn_list(List, optional):  A list of cost anomaly subscription ARNs. . Defaults to None.
        monitor_arn(str, optional):  Cost anomaly monitor ARNs. . Defaults to None.
        next_page_token(str, optional):  The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. . Defaults to None.
        max_results(int, optional):  The number of entries a paginated response contains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.subscription.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.subscription.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_anomaly_subscriptions",
        op_kwargs={
            "SubscriptionArnList": subscription_arn_list,
            "MonitorArn": monitor_arn,
            "NextPageToken": next_page_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    subscription_arn: str,
    threshold: float = None,
    frequency: str = None,
    monitor_arn_list: List = None,
    subscribers: List = None,
    subscription_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates an existing cost anomaly monitor subscription.

    Args:
        subscription_arn(str):  A cost anomaly subscription Amazon Resource Name (ARN). .
        threshold(float, optional):  The update to the threshold value for receiving notifications. . Defaults to None.
        frequency(str, optional):  The update to the frequency value at which subscribers will receive notifications. . Defaults to None.
        monitor_arn_list(List, optional):  A list of cost anomaly monitor ARNs. . Defaults to None.
        subscribers(List, optional):  The update to the subscriber list. . Defaults to None.
        subscription_name(str, optional):  The subscription's new name. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.subscription.update(ctx, subscription_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.subscription.update subscription_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="update_anomaly_subscription",
        op_kwargs={
            "SubscriptionArn": subscription_arn,
            "Threshold": threshold,
            "Frequency": frequency,
            "MonitorArnList": monitor_arn_list,
            "Subscribers": subscribers,
            "SubscriptionName": subscription_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, db_snapshot_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of DB snapshot attribute names and values for a manual DB snapshot. When sharing snapshots with other Amazon Web Services accounts, DescribeDBSnapshotAttributes returns the restore attribute and a list of IDs for the Amazon Web Services accounts that are authorized to copy or restore the manual DB snapshot. If all is included in the list of values for the restore attribute, then the manual DB snapshot is public and can be copied or restored by all Amazon Web Services accounts. To add or remove access for an Amazon Web Services account to copy or restore a manual DB snapshot, or to make the manual DB snapshot public or private, use the ModifyDBSnapshotAttribute API action.

    Args:
        db_snapshot_identifier(str): The identifier for the DB snapshot to describe the attributes for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.attribute.describe_all(
                ctx, db_snapshot_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.attribute.describe_all db_snapshot_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_snapshot_attributes",
        op_kwargs={"DBSnapshotIdentifier": db_snapshot_identifier},
    )


async def modify(
    hub,
    ctx,
    db_snapshot_identifier: str,
    attribute_name: str,
    values_to_add: List = None,
    values_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an attribute and values to, or removes an attribute and values from, a manual DB snapshot. To share a manual DB snapshot with other Amazon Web Services accounts, specify restore as the AttributeName and use the ValuesToAdd parameter to add a list of IDs of the Amazon Web Services accounts that are authorized to restore the manual DB snapshot. Uses the value all to make the manual DB snapshot public, which means it can be copied or restored by all Amazon Web Services accounts.  Don't add the all value for any manual DB snapshots that contain private information that you don't want available to all Amazon Web Services accounts.  If the manual DB snapshot is encrypted, it can be shared, but only by specifying a list of authorized Amazon Web Services account IDs for the ValuesToAdd parameter. You can't use all as a value for that parameter in this case. To view which Amazon Web Services accounts have access to copy or restore a manual DB snapshot, or whether a manual DB snapshot public or private, use the DescribeDBSnapshotAttributes API action. The accounts are returned as values for the restore attribute.

    Args:
        db_snapshot_identifier(str): The identifier for the DB snapshot to modify the attributes for.
        attribute_name(str): The name of the DB snapshot attribute to modify. To manage authorization for other Amazon Web Services accounts to copy or restore a manual DB snapshot, set this value to restore.  To view the list of attributes available to modify, use the DescribeDBSnapshotAttributes API action. .
        values_to_add(List, optional): A list of DB snapshot attributes to add to the attribute specified by AttributeName. To authorize other Amazon Web Services accounts to copy or restore a manual snapshot, set this list to include one or more Amazon Web Services account IDs, or all to make the manual DB snapshot restorable by any Amazon Web Services account. Do not add the all value for any manual DB snapshots that contain private information that you don't want available to all Amazon Web Services accounts. Defaults to None.
        values_to_remove(List, optional): A list of DB snapshot attributes to remove from the attribute specified by AttributeName. To remove authorization for other Amazon Web Services accounts to copy or restore a manual snapshot, set this list to include one or more Amazon Web Services account identifiers, or all to remove authorization for any Amazon Web Services account to copy or restore the DB snapshot. If you specify all, an Amazon Web Services account whose account ID is explicitly added to the restore attribute can still copy or restore the manual DB snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.snapshot.attribute.modify(
                ctx, db_snapshot_identifier=value, attribute_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.snapshot.attribute.modify db_snapshot_identifier=value, attribute_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_db_snapshot_attribute",
        op_kwargs={
            "DBSnapshotIdentifier": db_snapshot_identifier,
            "AttributeName": attribute_name,
            "ValuesToAdd": values_to_add,
            "ValuesToRemove": values_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    subnets: List = None,
    subnet_mappings: List = None,
    security_groups: List = None,
    scheme: str = None,
    tags: List = None,
    type_: str = None,
    ip_address_type: str = None,
    customer_owned_ipv4_pool: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. For more information, see the following:    Application Load Balancers     Network Load Balancers     Gateway Load Balancers    This operation is idempotent, which means that it completes at most one time. If you attempt to create multiple load balancers with the same settings, each call succeeds.

    Args:
        name(str): The name of the load balancer. This name must be unique per region per account, can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, must not begin or end with a hyphen, and must not begin with "internal-".
        subnets(List, optional): The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings. [Application Load Balancers] You must specify subnets from at least two Availability Zones. [Application Load Balancers on Outposts] You must specify one Outpost subnet. [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones. [Network Load Balancers] You can specify subnets from one or more Availability Zones. [Gateway Load Balancers] You can specify subnets from one or more Availability Zones. Defaults to None.
        subnet_mappings(List, optional): The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings. [Application Load Balancers] You must specify subnets from at least two Availability Zones. You cannot specify Elastic IP addresses for your subnets. [Application Load Balancers on Outposts] You must specify one Outpost subnet. [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones. [Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet. [Gateway Load Balancers] You can specify subnets from one or more Availability Zones. You cannot specify Elastic IP addresses for your subnets. Defaults to None.
        security_groups(List, optional): [Application Load Balancers] The IDs of the security groups for the load balancer. Defaults to None.
        scheme(str, optional): The nodes of an Internet-facing load balancer have public IP addresses. The DNS name of an Internet-facing load balancer is publicly resolvable to the public IP addresses of the nodes. Therefore, Internet-facing load balancers can route requests from clients over the internet. The nodes of an internal load balancer have only private IP addresses. The DNS name of an internal load balancer is publicly resolvable to the private IP addresses of the nodes. Therefore, internal load balancers can route requests only from clients with access to the VPC for the load balancer. The default is an Internet-facing load balancer. You cannot specify a scheme for a Gateway Load Balancer. Defaults to None.
        tags(List, optional): The tags to assign to the load balancer. Defaults to None.
        type_(str, optional): The type of load balancer. The default is application. Defaults to None.
        ip_address_type(str, optional): The type of IP addresses used by the subnets for your load balancer. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses). Internal load balancers must use ipv4. Defaults to None.
        customer_owned_ipv4_pool(str, optional): [Application Load Balancers on Outposts] The ID of the customer-owned address pool (CoIP pool). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.load_balancer.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.load_balancer.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="create_load_balancer",
        op_kwargs={
            "Name": name,
            "Subnets": subnets,
            "SubnetMappings": subnet_mappings,
            "SecurityGroups": security_groups,
            "Scheme": scheme,
            "Tags": tags,
            "Type": type_,
            "IpAddressType": ip_address_type,
            "CustomerOwnedIpv4Pool": customer_owned_ipv4_pool,
        },
    )


async def delete(hub, ctx, load_balancer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. Deleting a load balancer also deletes its listeners. You can't delete a load balancer if deletion protection is enabled. If the load balancer does not exist or has already been deleted, the call succeeds. Deleting a load balancer does not affect its registered targets. For example, your EC2 instances continue to run and are still registered to their target groups. If you no longer need these EC2 instances, you can stop or terminate them.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.load_balancer.init.delete(ctx, load_balancer_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.load_balancer.init.delete load_balancer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="delete_load_balancer",
        op_kwargs={"LoadBalancerArn": load_balancer_arn},
    )


async def describe_all(
    hub,
    ctx,
    load_balancer_arns: List = None,
    names: List = None,
    marker: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified load balancers or all of your load balancers.

    Args:
        load_balancer_arns(List, optional): The Amazon Resource Names (ARN) of the load balancers. You can specify up to 20 load balancers in a single call. Defaults to None.
        names(List, optional): The names of the load balancers. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.load_balancer.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.load_balancer.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_load_balancers",
        op_kwargs={
            "LoadBalancerArns": load_balancer_arns,
            "Names": names,
            "Marker": marker,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dataset_import_job_name: str,
    dataset_arn: str,
    data_source: Dict,
    timestamp_format: str = None,
    time_zone: str = None,
    use_geolocation_for_time_zone: bool = None,
    geolocation_format: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports your training data to an Amazon Forecast dataset. You provide the location of your training data in an Amazon Simple Storage Service (Amazon S3) bucket and the Amazon Resource Name (ARN) of the dataset that you want to import the data to. You must specify a DataSource object that includes an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the data, as Amazon Forecast makes a copy of your data and processes it in an internal AWS system. For more information, see aws-forecast-iam-roles. The training data must be in CSV format. The delimiter must be a comma (,). You can specify the path to a specific CSV file, the S3 bucket, or to a folder in the S3 bucket. For the latter two cases, Amazon Forecast imports all files up to the limit of 10,000 files. Because dataset imports are not aggregated, your most recent dataset import is the one that is used when training a predictor or generating a forecast. Make sure that your most recent dataset import contains all of the data you want to model off of, and not just the new data collected since the previous import. To get a list of all your dataset import jobs, filtered by specified criteria, use the ListDatasetImportJobs operation.

    Args:
        dataset_import_job_name(str): The name for the dataset import job. We recommend including the current timestamp in the name, for example, 20190721DatasetImport. This can help you avoid getting a ResourceAlreadyExistsException exception.
        dataset_arn(str): The Amazon Resource Name (ARN) of the Amazon Forecast dataset that you want to import data to.
        data_source(Dict): The location of the training data to import and an AWS Identity and Access Management (IAM) role that Amazon Forecast can assume to access the data. The training data must be stored in an Amazon S3 bucket. If encryption is used, DataSource must include an AWS Key Management Service (KMS) key and the IAM role must allow Amazon Forecast permission to access the key. The KMS key and IAM role must match those specified in the EncryptionConfig parameter of the CreateDataset operation.
        timestamp_format(str, optional): The format of timestamps in the dataset. The format that you specify depends on the DataFrequency specified when the dataset was created. The following formats are supported   "yyyy-MM-dd" For the following data frequencies: Y, M, W, and D   "yyyy-MM-dd HH:mm:ss" For the following data frequencies: H, 30min, 15min, and 1min; and optionally, for: Y, M, W, and D   If the format isn't specified, Amazon Forecast expects the format to be "yyyy-MM-dd HH:mm:ss". Defaults to None.
        time_zone(str, optional): A single time zone for every item in your dataset. This option is ideal for datasets with all timestamps within a single time zone, or if all timestamps are normalized to a single time zone.  Refer to the Joda-Time API for a complete list of valid time zone names. Defaults to None.
        use_geolocation_for_time_zone(bool, optional): Automatically derive time zone information from the geolocation attribute. This option is ideal for datasets that contain timestamps in multiple time zones and those timestamps are expressed in local time. Defaults to None.
        geolocation_format(str, optional): The format of the geolocation attribute. The geolocation attribute can be formatted in one of two ways:    LAT_LONG - the latitude and longitude in decimal format (Example: 47.61_-122.33).    CC_POSTALCODE (US Only) - the country code (US), followed by the 5-digit ZIP code (Example: US_98121).  . Defaults to None.
        tags(List, optional): The optional metadata that you apply to the dataset import job to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.import_job.create(
                ctx, dataset_import_job_name=value, dataset_arn=value, data_source=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.import_job.create dataset_import_job_name=value, dataset_arn=value, data_source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_dataset_import_job",
        op_kwargs={
            "DatasetImportJobName": dataset_import_job_name,
            "DatasetArn": dataset_arn,
            "DataSource": data_source,
            "TimestampFormat": timestamp_format,
            "TimeZone": time_zone,
            "UseGeolocationForTimeZone": use_geolocation_for_time_zone,
            "GeolocationFormat": geolocation_format,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, dataset_import_job_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a dataset import job created using the CreateDatasetImportJob operation. You can delete only dataset import jobs that have a status of ACTIVE or CREATE_FAILED. To get the status, use the DescribeDatasetImportJob operation.

    Args:
        dataset_import_job_arn(str): The Amazon Resource Name (ARN) of the dataset import job to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.import_job.delete(
                ctx, dataset_import_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.import_job.delete dataset_import_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_dataset_import_job",
        op_kwargs={"DatasetImportJobArn": dataset_import_job_arn},
    )


async def describe(hub, ctx, dataset_import_job_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a dataset import job created using the CreateDatasetImportJob operation. In addition to listing the parameters provided in the CreateDatasetImportJob request, this operation includes the following properties:    CreationTime     LastModificationTime     DataSize     FieldStatistics     Status     Message - If an error occurred, information about the error.

    Args:
        dataset_import_job_arn(str): The Amazon Resource Name (ARN) of the dataset import job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.import_job.describe(
                ctx, dataset_import_job_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.import_job.describe dataset_import_job_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_dataset_import_job",
        op_kwargs={"DatasetImportJobArn": dataset_import_job_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of dataset import jobs created using the CreateDatasetImportJob operation. For each import job, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the ARN with the DescribeDatasetImportJob operation. You can filter the list by providing an array of Filter objects.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.
        filters(List, optional): An array of filters. For each filter, you provide a condition and a match statement. The condition is either IS or IS_NOT, which specifies whether to include or exclude the datasets that match the statement from the list, respectively. The match statement consists of a key and a value.  Filter properties     Condition - The condition to apply. Valid values are IS and IS_NOT. To include the datasets that match the statement, specify IS. To exclude matching datasets, specify IS_NOT.    Key - The name of the parameter to filter on. Valid values are DatasetArn and Status.    Value - The value to match.   For example, to list all dataset import jobs whose status is ACTIVE, you specify the following filter:  "Filters": [ { "Condition": "IS", "Key": "Status", "Value": "ACTIVE" } ] . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.import_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.import_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_dataset_import_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, index_id: str, document_info_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the indexing status for one or more documents submitted with the  BatchPutDocument operation. When you use the BatchPutDocument operation, documents are indexed asynchronously. You can use the BatchGetDocumentStatus operation to get the current status of a list of documents so that you can determine if they have been successfully indexed. You can also use the BatchGetDocumentStatus operation to check the status of the  BatchDeleteDocument operation. When a document is deleted from the index, Amazon Kendra returns NOT_FOUND as the status.

    Args:
        index_id(str): The identifier of the index to add documents to. The index ID is returned by the  CreateIndex  operation.
        document_info_list(List): A list of DocumentInfo objects that identify the documents for which to get the status. You identify the documents by their document ID and optional attributes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.get_document_status.batch(
                ctx, index_id=value, document_info_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.get_document_status.batch index_id=value, document_info_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="batch_get_document_status",
        op_kwargs={"IndexId": index_id, "DocumentInfoList": document_info_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def forget(hub, ctx, room_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Forgets smart home appliances associated to a room.

    Args:
        room_arn(str): The room that the appliances are associated with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.smart_home_appliance.init.forget(
                ctx, room_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.smart_home_appliance.init.forget room_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="forget_smart_home_appliances",
        op_kwargs={"RoomArn": room_arn},
    )


async def list_all(
    hub, ctx, room_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the smart home appliances associated with a room.

    Args:
        room_arn(str): The room that the appliances are associated with.
        max_results(int, optional): The maximum number of appliances to be returned, per paginated calls. Defaults to None.
        next_token(str, optional): The tokens used for pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.smart_home_appliance.init.list_all(
                ctx, room_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.smart_home_appliance.init.list_all room_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_smart_home_appliances",
        op_kwargs={
            "RoomArn": room_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of the tags associated with the specified resource.


        Args:
            resource_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the resource that's associated with the tags.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.tags_for_resource.list(ctx, resource_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    Sends a list of asset property values to IoT SiteWise. Each value is a timestamp-quality-value (TQV) data point. For more information, see Ingesting data using the API in the IoT SiteWise User Guide. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.    With respect to Unix epoch time, IoT SiteWise accepts only TQVs that have a timestamp of no more than 7 days in the past and no more than 10 minutes in the future. IoT SiteWise rejects timestamps outside of the inclusive range of [-7 days, +10 minutes] and returns a TimestampOutOfRangeException error. For each asset property, IoT SiteWise overwrites TQVs with duplicate timestamps unless the newer TQV has a different quality. For example, if you store a TQV {T1, GOOD, V1}, then storing {T1, GOOD, V2} replaces the existing TQV.  IoT SiteWise authorizes access to each BatchPutAssetPropertyValue entry individually. For more information, see BatchPutAssetPropertyValue authorization in the IoT SiteWise User Guide.

    Args:
        entries(List): The list of asset property value entries for the batch put request. You can specify up to 10 entries per request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.put_asset_property_value.batch(ctx, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.put_asset_property_value.batch entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="batch_put_asset_property_value",
        op_kwargs={"entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    instance_id: str,
    http_tokens: str = None,
    http_put_response_hop_limit: int = None,
    http_endpoint: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify the instance metadata parameters on a running or stopped instance. When you modify the parameters on a stopped instance, they are applied when the instance is started. When you modify the parameters on a running instance, the API responds with a state of “pending”. After the parameter modifications are successfully applied to the instance, the state of the modifications changes from “pending” to “applied” in subsequent describe-instances API calls. For more information, see Instance metadata and user data in the Amazon EC2 User Guide.

    Args:
        instance_id(str): The ID of the instance.
        http_tokens(str, optional): The state of token usage for your instance metadata requests. If the parameter is not specified in the request, the default state is optional. If the state is optional, you can choose to retrieve instance metadata with or without a signed token header on your request. If you retrieve the IAM role credentials without a token, the version 1.0 role credentials are returned. If you retrieve the IAM role credentials using a valid signed token, the version 2.0 role credentials are returned. If the state is required, you must send a signed token header with any instance metadata retrieval requests. In this state, retrieving the IAM role credential always returns the version 2.0 credentials; the version 1.0 credentials are not available. Defaults to None.
        http_put_response_hop_limit(int, optional): The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. If no parameter is specified, the existing state is maintained. Possible values: Integers from 1 to 64. Defaults to None.
        http_endpoint(str, optional): This parameter enables or disables the HTTP metadata endpoint on your instances. If the parameter is not specified, the existing state is maintained.  If you specify a value of disabled, you will not be able to access your instance metadata. . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.metadata_option.modify(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.metadata_option.modify instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_metadata_options",
        op_kwargs={
            "InstanceId": instance_id,
            "HttpTokens": http_tokens,
            "HttpPutResponseHopLimit": http_put_response_hop_limit,
            "HttpEndpoint": http_endpoint,
            "DryRun": dry_run,
        },
    )
